@@ -4,11 +4,11 @@
 #'
 #' @param ped : Pedigree \code{data.frame} with columns for animal, sire, and dam identification.
 #'
-#' @param AF : Vector of allele frequencies at different loci for the genotypes to be simulated.
+#' @param AF : Vector of allele frequencies at different loci for the genotypes to be simulated. If no value is provided, it will be randomly sampled from a uniform distribution with min = 0.01 and max = 0.99.
 #'
 #' @param mut.rate : Vector of mutation rates at different loci for the genotypes to be simulated, default = 0 for no mutation.
 #'
-#' @return M : The simulated genotype \code{data.frame} with rows corresponding to animals(in the same order as in the pedigree) and columns corresponding to markers.
+#' @return M : The simulated genotype \code{data.frame} with rows corresponding to animals (in the same order as in the pedigree) and columns corresponding to markers.
 #'
 #' @details
 #' Only diploid and bi-allelic situations are covered.
@@ -22,10 +22,14 @@
 #' gen = simulateGen(ped, AF, mut.rate)
 #'
 #' @export
-simulateGen <- function(ped, AF, mut.rate=0) {
+simulateGen <- function(ped, AF=c(), mut.rate=0) {
     colnames(ped) = c("ID","SIRE","DAM")
-    stopifnot(min(AF)>=0.01)
-    stopifnot(max(AF)<=0.99)
+    if(length(AF)==0) {
+        AF = runif(ncol(M), min=0.01, max=0.99)
+    } else {
+        stopifnot(min(AF)>=0.01)
+        stopifnot(max(AF)<=0.99)
+    }
     if(!identical(mut.rate, 0)) {
         stopifnot(length(AF)==length(mut.rate))
         stopifnot(min(mut.rate)>=0)
