@@ -249,7 +249,8 @@ simulatePed <- function(F0size, Va0, Ve, littersize=1, ngen, mort.rate=0, overla
                 }
             }
             # Set mates
-            SIRES = c(rep(sires, each=floor(nf/nm)), sires[0:(nf-length(sires)*floor(nf/nm))])
+            SIRES = rep(sires, each=floor(nf/nm))
+            if(length(SIRES) < length(dams)) SIRES = c(SIRES, sires[1:(nf-length(sires)*floor(nf/nm))])
             SIRES = SIRES[order(match(SIRES, sires))]
             tmp = data.frame(SIRE=SIRES, DAM=dams)
             # Append the next generation
